==> simulatorAPMS_1.8.0.tar.gz: simulatorAPMS/man/simulatorD.Rd <==
\name{simulatorD}
\alias{simulatorD}

\title{Function that simulates deformation errors}
\description{
  The simulatorD function is the function that operates on deformed
  baits. It takes in a vector of deformed baits, and for each bait B, it
  finds all the proteins interacting with it in the ISI. When it has
  calculated this set of proteins, it calls the applyDeformationErrors
  function and gets the subset of proteins as the FN hits. It changes
  these interactions from 1 to 0 in the PPCM matrix creating the error model.
}
\usage{
simulatorD(deformedBaits, rateD, TSNMat, exMat)
}

\arguments{
  \item{deformedBaits}{Vector of deformed baits}
  \item{rateD}{Either a single rate or a vector of rates which the
    experiment will record FN's }
  \item{TSNMat}{The PPCM matrix }
  \item{exMat}{The experimental matrix that carries the FN/FP }
}
\details{
  One interesting aspect of this function is that the rateD can either be
  a vector of the same length as the vector of deformed baits, or it can
  be a single rate which is applied to all the deformed baits. The function uses each rate to decide how deformed the bait has become and will create FN observations based on this data.
}
\value{
  The return value of this function is an PPCM matrix with error to reflect the
  FN's that have been induced by applyDeformationErrors
}

\author{Tony Chiang}




\seealso{\code{\link{applyDeformationError}}}
\examples{

library(apComplex)
data(MBMEcHMSPCI)
data(HMSPCI)
vBaits = rownames(HMSPCI)[1:10]
PPI = MBMEcHMSPCI %*% t(MBMEcHMSPCI)
mode(PPI) = "logical"
mode(PPI) = "numeric"
exMat = PPI[vBaits,]
deformedBaits = vBaits[3]
rateD = 0.9
test = simulatorD(deformedBaits, rateD, MBMEcHMSPCI, exMat) 
test[3,]

}
\keyword{misc}

==> simulatorAPMS_1.22.0.tar.gz: simulatorAPMS/man/simulatorD.Rd <==
\name{simulatorD}
\alias{simulatorD}

\title{Function that simulates deformation errors}
\description{
  The simulatorD function is the function that operates on deformed
  baits. It takes in a vector of deformed baits, and for each bait B, it
  finds all the proteins interacting with it in the ISI. When it has
  calculated this set of proteins, it calls the applyDeformationErrors
  function and gets the subset of proteins as the FN hits. It changes
  these interactions from 1 to 0 in the PPCM matrix creating the error model.
}
\usage{
simulatorD(deformedBaits, rateD, TSNMat, exMat)
}

\arguments{
  \item{deformedBaits}{Vector of deformed baits}
  \item{rateD}{Either a single rate or a vector of rates which the
    experiment will record FN's }
  \item{TSNMat}{The PPCM matrix }
  \item{exMat}{The experimental matrix that carries the FN/FP }
}
\details{
  One interesting aspect of this function is that the rateD can either be
  a vector of the same length as the vector of deformed baits, or it can
  be a single rate which is applied to all the deformed baits. The function uses each rate to decide how deformed the bait has become and will create FN observations based on this data.
}
\value{
  The return value of this function is an PPCM matrix with error to reflect the
  FN's that have been induced by applyDeformationErrors
}

\author{Tony Chiang}




\seealso{\code{\link{applyDeformationError}}}
\examples{

data(MBMEcHMSPCI)
data(HMSPCI)
vBaits = rownames(MBMEcHMSPCI)[1:10]
PPI = MBMEcHMSPCI %*% t(MBMEcHMSPCI)
mode(PPI) = "logical"
mode(PPI) = "numeric"
exMat = PPI[vBaits[2:4],]
deformedBaits = vBaits[3]
rateD = 0.9
test = simulatorD(deformedBaits, rateD, MBMEcHMSPCI, exMat) 
test[3,]

}
\keyword{misc}
